# coding: utf-8

# flake8: noqa

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "AdvancedSearchApi",
    "ApplicationCategoriesApi",
    "ApplicationReportDataApi",
    "ApplicationsApi",
    "AuditLogsApi",
    "AutoPolicyWaiverExclusionsApi",
    "AutoPolicyWaiversApi",
    "CPEMatchingConfigurationApi",
    "ClaimComponentsApi",
    "ComponentLabelsApi",
    "ComponentSearchApi",
    "ComponentsApi",
    "CompositeSourceControlApi",
    "CompositeSourceControlValidatorApi",
    "ConfigCrowdApi",
    "ConfigJiraApi",
    "ConfigMailApi",
    "ConfigProxyServerApi",
    "ConfigReverseProxyAuthenticationApi",
    "ConfigSAMLApi",
    "ConfigSourceControlApi",
    "ConfigZscalerApi",
    "ConfigurationApi",
    "ConfigureArtifactoryConnectionApi",
    "CycloneDXApi",
    "DataRetentionPoliciesApi",
    "DeveloperPrioritiesApi",
    "EndpointsApi",
    "FeatureConfigurationApi",
    "FirewallApi",
    "LicenseLegalMetadataReportApi",
    "LicenseLegalMetadataTemplateApi",
    "LicenseOverridesApi",
    "OrganizationsApi",
    "PoliciesApi",
    "PolicyEvaluationApi",
    "PolicyViolationDetailsApi",
    "PolicyWaiverReasonsApi",
    "PolicyWaiverRequestsApi",
    "PolicyWaiversApi",
    "ProductLicenseApi",
    "ReportsApi",
    "RepositoriesApi",
    "RoleMembershipsApi",
    "RolesApi",
    "SBOMApi",
    "SPDXApi",
    "SecurityVulnerabilityOverridesApi",
    "SolutionsApi",
    "SourceControlApi",
    "SourceControlMetricsApi",
    "ThirdPartyAnalysisApi",
    "UserTokensApi",
    "UsersApi",
    "VulnerabilityDetailsApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "Action",
    "ApiApplicationBaseDTO",
    "ApiApplicationCategoriesDTO",
    "ApiApplicationCategoriesListDTO",
    "ApiApplicationCategoryDTO",
    "ApiApplicationDTO",
    "ApiApplicationEvaluationCommitDTO",
    "ApiApplicationEvaluationResultDTOV2",
    "ApiApplicationEvaluationStatusDTOV2",
    "ApiApplicationListDTO",
    "ApiApplicationReportDTOV2",
    "ApiApplicationTagDTO",
    "ApiApplicationViolationDTOV2",
    "ApiApplicationViolationListDTOV2",
    "ApiApplicationWaiverDTO",
    "ApiAppliedLicenseOverridesDTO",
    "ApiArtifactoryConnectionDTO",
    "ApiArtifactoryConnectionStatusRequestDTO",
    "ApiArtifactoryConnectionStatusResponseDTO",
    "ApiAutoPolicyWaiverDTO",
    "ApiAutoPolicyWaiverExclusionRequestDTO",
    "ApiAutoPolicyWaiverExclusionResponseDTO",
    "ApiAutoPolicyWaiverStatusDTO",
    "ApiBulkWaiversDTO",
    "ApiComponentChangeActionDTO",
    "ApiComponentDTOV2",
    "ApiComponentDetailsDTOV2",
    "ApiComponentDetailsRequestDTOV2",
    "ApiComponentDetailsResultDTOV2",
    "ApiComponentEvaluationRequestDTOV2",
    "ApiComponentEvaluationResultDTOV2",
    "ApiComponentEvaluationTicketDTOV2",
    "ApiComponentIdentifierDTOV2",
    "ApiComponentOrPurlIdentifierDTOV2",
    "ApiComponentPolicyViolationDTO",
    "ApiComponentPolicyViolationListDTOV2",
    "ApiComponentPolicyWaiversDTO",
    "ApiComponentProjectDataDTO",
    "ApiComponentProjectMetadataDTO",
    "ApiComponentProjectScmDTO",
    "ApiComponentProjectScmDetailsDTO",
    "ApiComponentProjectScmMetadataDTO",
    "ApiComponentReleasedFromQuarantineDTO",
    "ApiComponentRemediationValueDTO",
    "ApiComponentTransitivePolicyViolationsDTO",
    "ApiComponentWaiversDTO",
    "ApiComponentsInQuarantineDTO",
    "ApiCompositeSourceControlDTO",
    "ApiCompositeValueDTOBoolean",
    "ApiCompositeValueDTOInteger",
    "ApiCompositeValueDTOString",
    "ApiConditionFactReasonDTO",
    "ApiConstraintFactDTO",
    "ApiConstraintViolationDTO",
    "ApiConstraintViolationReasonDTO",
    "ApiContainerImageWaiverDTO",
    "ApiCrossStageViolationDTOV2",
    "ApiCrowdConfigurationDTO",
    "ApiDataRetentionPoliciesDTO",
    "ApiDependencyDataDTO",
    "ApiDependencyTreeNodeDTO",
    "ApiDependencyTreeResponseDTO",
    "ApiEnhancedPolicyViolationDTOV2",
    "ApiEvaluationResultCounterDTO",
    "ApiFirewallComponentDTO",
    "ApiFirewallComponentDTOResult",
    "ApiFirewallMetricsResultDTO",
    "ApiFirewallQuarantineSummaryDTO",
    "ApiFirewallQuarantinedComponentDto",
    "ApiFirewallQuarantinedComponentDtoResult",
    "ApiFirewallReleaseQuarantineConfigDTO",
    "ApiFirewallReleaseQuarantineSummaryDTO",
    "ApiGlobalInformationDTOV2",
    "ApiHashComponentIdentifierDTO",
    "ApiHashComponentIdentifiersDTO",
    "ApiJiraConfigurationDTO",
    "ApiLabelDTO",
    "ApiLicenseDTO",
    "ApiLicenseDataDTO",
    "ApiLicenseDataDTOV2",
    "ApiLicenseLegalApplicationReportDTO",
    "ApiLicenseLegalComponentDTO",
    "ApiLicenseLegalComponentReportDTO",
    "ApiLicenseLegalCopyrightDTO",
    "ApiLicenseLegalDataDTO",
    "ApiLicenseLegalFileDTO",
    "ApiLicenseLegalMetadataDTO",
    "ApiLicenseLegalObligationDTO",
    "ApiLicenseLegalStageScanDTO",
    "ApiLicenseOverrideDTO",
    "ApiLicenseThreatDTOV2",
    "ApiLicensedSolutionDTO",
    "ApiMailConfigurationDTO",
    "ApiMalwareComponentEvaluationRequest",
    "ApiMalwareComponentEvaluationRequestList",
    "ApiMatchStateSummaryDTOV2",
    "ApiMemberDTO",
    "ApiMetricsReportingAggregationDTOV2",
    "ApiMetricsReportingDTOV2",
    "ApiMetricsReportingQueryDTOV2",
    "ApiMoveApplicationResponseDTOV2",
    "ApiOrganizationDTO",
    "ApiOrganizationListDTO",
    "ApiOwnerArtifactoryConnectionDTO",
    "ApiOwnerDTO",
    "ApiPageResultPrioritizedComponent",
    "ApiPolicyDTO",
    "ApiPolicyListDTO",
    "ApiPolicyViolationDTOV2",
    "ApiPolicyViolationDiffDTO",
    "ApiPolicyViolationForDiffDTO",
    "ApiPolicyViolationStageDTO",
    "ApiPolicyWaiverDTO",
    "ApiPolicyWaiverReasonDTO",
    "ApiPolicyWaiverRequestDTO",
    "ApiPolicyWaiverRequestOptionsDTO",
    "ApiPolicyWaiverRequestReviewDTO",
    "ApiPolicyWaiverRequestsApplicableToViolationDTO",
    "ApiPolicyWaiversApplicableToViolationDTO",
    "ApiPromoteScanRequestDTOV2",
    "ApiProxyServerConfigurationDTO",
    "ApiPullRequestResult",
    "ApiPullRequestResults",
    "ApiReportComponentDTOV2",
    "ApiReportComponentPolicyViolationsDTOV2",
    "ApiReportConstraintConditionDTOV2",
    "ApiReportConstraintViolationDTOV2",
    "ApiReportHistoryDTO",
    "ApiReportPolicyDataDTOV2",
    "ApiReportPolicyViolationDTOV2",
    "ApiReportRawDataDTOV2",
    "ApiReportResultsDTO",
    "ApiReportRetentionPoliciesDTO",
    "ApiReportRetentionPolicyDTO",
    "ApiRepositoryComponentDTO",
    "ApiRepositoryComponentEvaluationRequest",
    "ApiRepositoryComponentEvaluationRequestList",
    "ApiRepositoryComponentEvaluationResult",
    "ApiRepositoryComponentEvaluationResultList",
    "ApiRepositoryComponentPath",
    "ApiRepositoryComponentPolicyViolationDTO",
    "ApiRepositoryComponentsInQuarantineDTO",
    "ApiRepositoryContainerDTO",
    "ApiRepositoryDTO",
    "ApiRepositoryListDTO",
    "ApiRepositoryManagerDTO",
    "ApiRepositoryManagerListDTO",
    "ApiRepositoryPathResponseDTO",
    "ApiRepositoryPathVersions",
    "ApiRepositoryWaiverDTO",
    "ApiRequestPolicyWaiverDTO",
    "ApiReverseProxyAuthenticationConfigurationDTO",
    "ApiRoleDTO",
    "ApiRoleListDTO",
    "ApiRoleMemberMappingDTO",
    "ApiRoleMemberMappingListDTO",
    "ApiSamlConfigurationDTO",
    "ApiSamlConfigurationResponseDTO",
    "ApiSearchCriteriaDTOV2",
    "ApiSearchResultDTOV2",
    "ApiSearchResultsDTOV2",
    "ApiSecurityDataDTO",
    "ApiSecurityIssueAnalysisDTO",
    "ApiSecurityIssueDTO",
    "ApiSecurityVulnerabilityOverrideDTOV2",
    "ApiSecurityVulnerabilityOverrideResponseDTOV2",
    "ApiSourceControlConfigurationDTO",
    "ApiSourceControlDTO",
    "ApiSourceControlEvaluationRequestDTO",
    "ApiStagePolicyViolationComponentDTO",
    "ApiStaleApplicationEvaluationDTO",
    "ApiStaleEvaluationStageDTO",
    "ApiStaleEvaluationsDTO",
    "ApiStaleRepositoryEvaluationDTO",
    "ApiStaleWaiverDTO",
    "ApiStaleWaiversResponseDTO",
    "ApiStatusDTO",
    "ApiSuccessMetricsRetentionPolicyDTO",
    "ApiSuggestedVersionChangeOptionDTO",
    "ApiTagDTO",
    "ApiThirdPartyScanResultDTO",
    "ApiThirdPartyScanTicketDTO",
    "ApiUserDTO",
    "ApiUserListDTO",
    "ApiUserTokenDTO",
    "ApiUserTokenExistsDTO",
    "ApiVersionChangeOptionDTO",
    "ApiWaivedPolicyViolationDTO",
    "ApiWaiverOptionsDTO",
    "ApiZScalerConfigurationDTO",
    "ApiZScalerQuotaDTO",
    "ApplicableContext",
    "ApplicableLabels",
    "ApplicableTagsDTO",
    "ApplicationTag",
    "ApplicationTagsByOwnerDTO",
    "AppliedTagsDTO",
    "AttachmentText",
    "AttributionReportTemplateDTO",
    "BulkSecurityVulnerabilityDataDTO",
    "ComponentDisplayName",
    "ComponentDisplayNamePart",
    "ComponentFact",
    "ComponentIdentifier",
    "ComponentLocator",
    "ComponentObligationAttributionDTO",
    "ConditionFact",
    "ConfigurationValidationResult",
    "ConstraintFact",
    "ContainerImageInQuarantineData",
    "ContainerImageInQuarantineDataResult",
    "CpeMatchingConfigurationRequest",
    "CweId",
    "CweIdDTO",
    "DevelopmentPrioritizationResults",
    "EpssData",
    "GetSuggestedRemediationForComponent200Response",
    "GroupingByDTO",
    "ImportSbomRequest",
    "InnerSourceData",
    "InsertOrUpdateSamlConfigurationRequest",
    "InstallLicenseRequest",
    "KevData",
    "LabelsByOwner",
    "LegalSourceLinkDTO",
    "LicenseObligationDTO",
    "LicenseOverride",
    "LicenseOverrideByOwner",
    "LicenseThreatGroupDTO",
    "MalwareCategory",
    "MalwareDefenseData",
    "MalwareDefenseResponseList",
    "MoveOrganizationResponseDTO",
    "PolicyAlert",
    "PolicyContainerWaiverData",
    "PolicyContainerWaiverDataResult",
    "PolicyEvaluationResult",
    "PolicyFact",
    "PolicyOwner",
    "PolicyTag",
    "PrioritizedComponent",
    "ReferenceLink",
    "ReferenceLinkDTO",
    "RootCause",
    "RootCauseDTO",
    "SCMUserMappingsDTO",
    "SCMUserMappingsResponseDTO",
    "SCMUserMatchingResultDTO",
    "SbomVulnerabilityAnalysisRequest",
    "SearchResultDTO",
    "SearchResultItemDTO",
    "SecurityVulnerabilityCustomData",
    "SecurityVulnerabilityCustomDataDTO",
    "SecurityVulnerabilityData",
    "SecurityVulnerabilityDataDTO",
    "SecurityVulnerabilitySeverity",
    "SecurityVulnerabilitySeverityDTO",
    "SecurityVulnerabilityWeakness",
    "SecurityVulnerabilityWeaknessDTO",
    "StageData",
    "Swid",
    "SystemConfig",
    "SystemConfigProperty",
    "TagsByOwnerDTO",
    "TriggerReference",
    "UserMapping",
    "ValidationError",
    "ValidationResult",
    "ValidationWarning",
    "VulnerabilityAnalysis",
    "VulnerabilitySource",
    "VulnerabilitySourceDTO",
]

# import apis into sdk package
from sonatype_iq_api_client.api.advanced_search_api import AdvancedSearchApi as AdvancedSearchApi
from sonatype_iq_api_client.api.application_categories_api import ApplicationCategoriesApi as ApplicationCategoriesApi
from sonatype_iq_api_client.api.application_report_data_api import ApplicationReportDataApi as ApplicationReportDataApi
from sonatype_iq_api_client.api.applications_api import ApplicationsApi as ApplicationsApi
from sonatype_iq_api_client.api.audit_logs_api import AuditLogsApi as AuditLogsApi
from sonatype_iq_api_client.api.auto_policy_waiver_exclusions_api import AutoPolicyWaiverExclusionsApi as AutoPolicyWaiverExclusionsApi
from sonatype_iq_api_client.api.auto_policy_waivers_api import AutoPolicyWaiversApi as AutoPolicyWaiversApi
from sonatype_iq_api_client.api.cpe_matching_configuration_api import CPEMatchingConfigurationApi as CPEMatchingConfigurationApi
from sonatype_iq_api_client.api.claim_components_api import ClaimComponentsApi as ClaimComponentsApi
from sonatype_iq_api_client.api.component_labels_api import ComponentLabelsApi as ComponentLabelsApi
from sonatype_iq_api_client.api.component_search_api import ComponentSearchApi as ComponentSearchApi
from sonatype_iq_api_client.api.components_api import ComponentsApi as ComponentsApi
from sonatype_iq_api_client.api.composite_source_control_api import CompositeSourceControlApi as CompositeSourceControlApi
from sonatype_iq_api_client.api.composite_source_control_validator_api import CompositeSourceControlValidatorApi as CompositeSourceControlValidatorApi
from sonatype_iq_api_client.api.config_crowd_api import ConfigCrowdApi as ConfigCrowdApi
from sonatype_iq_api_client.api.config_jira_api import ConfigJiraApi as ConfigJiraApi
from sonatype_iq_api_client.api.config_mail_api import ConfigMailApi as ConfigMailApi
from sonatype_iq_api_client.api.config_proxy_server_api import ConfigProxyServerApi as ConfigProxyServerApi
from sonatype_iq_api_client.api.config_reverse_proxy_authentication_api import ConfigReverseProxyAuthenticationApi as ConfigReverseProxyAuthenticationApi
from sonatype_iq_api_client.api.config_saml_api import ConfigSAMLApi as ConfigSAMLApi
from sonatype_iq_api_client.api.config_source_control_api import ConfigSourceControlApi as ConfigSourceControlApi
from sonatype_iq_api_client.api.config_zscaler_api import ConfigZscalerApi as ConfigZscalerApi
from sonatype_iq_api_client.api.configuration_api import ConfigurationApi as ConfigurationApi
from sonatype_iq_api_client.api.configure_artifactory_connection_api import ConfigureArtifactoryConnectionApi as ConfigureArtifactoryConnectionApi
from sonatype_iq_api_client.api.cyclone_dx_api import CycloneDXApi as CycloneDXApi
from sonatype_iq_api_client.api.data_retention_policies_api import DataRetentionPoliciesApi as DataRetentionPoliciesApi
from sonatype_iq_api_client.api.developer_priorities_api import DeveloperPrioritiesApi as DeveloperPrioritiesApi
from sonatype_iq_api_client.api.endpoints_api import EndpointsApi as EndpointsApi
from sonatype_iq_api_client.api.feature_configuration_api import FeatureConfigurationApi as FeatureConfigurationApi
from sonatype_iq_api_client.api.firewall_api import FirewallApi as FirewallApi
from sonatype_iq_api_client.api.license_legal_metadata_report_api import LicenseLegalMetadataReportApi as LicenseLegalMetadataReportApi
from sonatype_iq_api_client.api.license_legal_metadata_template_api import LicenseLegalMetadataTemplateApi as LicenseLegalMetadataTemplateApi
from sonatype_iq_api_client.api.license_overrides_api import LicenseOverridesApi as LicenseOverridesApi
from sonatype_iq_api_client.api.organizations_api import OrganizationsApi as OrganizationsApi
from sonatype_iq_api_client.api.policies_api import PoliciesApi as PoliciesApi
from sonatype_iq_api_client.api.policy_evaluation_api import PolicyEvaluationApi as PolicyEvaluationApi
from sonatype_iq_api_client.api.policy_violation_details_api import PolicyViolationDetailsApi as PolicyViolationDetailsApi
from sonatype_iq_api_client.api.policy_waiver_reasons_api import PolicyWaiverReasonsApi as PolicyWaiverReasonsApi
from sonatype_iq_api_client.api.policy_waiver_requests_api import PolicyWaiverRequestsApi as PolicyWaiverRequestsApi
from sonatype_iq_api_client.api.policy_waivers_api import PolicyWaiversApi as PolicyWaiversApi
from sonatype_iq_api_client.api.product_license_api import ProductLicenseApi as ProductLicenseApi
from sonatype_iq_api_client.api.reports_api import ReportsApi as ReportsApi
from sonatype_iq_api_client.api.repositories_api import RepositoriesApi as RepositoriesApi
from sonatype_iq_api_client.api.role_memberships_api import RoleMembershipsApi as RoleMembershipsApi
from sonatype_iq_api_client.api.roles_api import RolesApi as RolesApi
from sonatype_iq_api_client.api.sbom_api import SBOMApi as SBOMApi
from sonatype_iq_api_client.api.spdx_api import SPDXApi as SPDXApi
from sonatype_iq_api_client.api.security_vulnerability_overrides_api import SecurityVulnerabilityOverridesApi as SecurityVulnerabilityOverridesApi
from sonatype_iq_api_client.api.solutions_api import SolutionsApi as SolutionsApi
from sonatype_iq_api_client.api.source_control_api import SourceControlApi as SourceControlApi
from sonatype_iq_api_client.api.source_control_metrics_api import SourceControlMetricsApi as SourceControlMetricsApi
from sonatype_iq_api_client.api.third_party_analysis_api import ThirdPartyAnalysisApi as ThirdPartyAnalysisApi
from sonatype_iq_api_client.api.user_tokens_api import UserTokensApi as UserTokensApi
from sonatype_iq_api_client.api.users_api import UsersApi as UsersApi
from sonatype_iq_api_client.api.vulnerability_details_api import VulnerabilityDetailsApi as VulnerabilityDetailsApi

# import ApiClient
from sonatype_iq_api_client.api_response import ApiResponse as ApiResponse
from sonatype_iq_api_client.api_client import ApiClient as ApiClient
from sonatype_iq_api_client.configuration import Configuration as Configuration
from sonatype_iq_api_client.exceptions import OpenApiException as OpenApiException
from sonatype_iq_api_client.exceptions import ApiTypeError as ApiTypeError
from sonatype_iq_api_client.exceptions import ApiValueError as ApiValueError
from sonatype_iq_api_client.exceptions import ApiKeyError as ApiKeyError
from sonatype_iq_api_client.exceptions import ApiAttributeError as ApiAttributeError
from sonatype_iq_api_client.exceptions import ApiException as ApiException

# import models into sdk package
from sonatype_iq_api_client.models.action import Action as Action
from sonatype_iq_api_client.models.api_application_base_dto import ApiApplicationBaseDTO as ApiApplicationBaseDTO
from sonatype_iq_api_client.models.api_application_categories_dto import ApiApplicationCategoriesDTO as ApiApplicationCategoriesDTO
from sonatype_iq_api_client.models.api_application_categories_list_dto import ApiApplicationCategoriesListDTO as ApiApplicationCategoriesListDTO
from sonatype_iq_api_client.models.api_application_category_dto import ApiApplicationCategoryDTO as ApiApplicationCategoryDTO
from sonatype_iq_api_client.models.api_application_dto import ApiApplicationDTO as ApiApplicationDTO
from sonatype_iq_api_client.models.api_application_evaluation_commit_dto import ApiApplicationEvaluationCommitDTO as ApiApplicationEvaluationCommitDTO
from sonatype_iq_api_client.models.api_application_evaluation_result_dtov2 import ApiApplicationEvaluationResultDTOV2 as ApiApplicationEvaluationResultDTOV2
from sonatype_iq_api_client.models.api_application_evaluation_status_dtov2 import ApiApplicationEvaluationStatusDTOV2 as ApiApplicationEvaluationStatusDTOV2
from sonatype_iq_api_client.models.api_application_list_dto import ApiApplicationListDTO as ApiApplicationListDTO
from sonatype_iq_api_client.models.api_application_report_dtov2 import ApiApplicationReportDTOV2 as ApiApplicationReportDTOV2
from sonatype_iq_api_client.models.api_application_tag_dto import ApiApplicationTagDTO as ApiApplicationTagDTO
from sonatype_iq_api_client.models.api_application_violation_dtov2 import ApiApplicationViolationDTOV2 as ApiApplicationViolationDTOV2
from sonatype_iq_api_client.models.api_application_violation_list_dtov2 import ApiApplicationViolationListDTOV2 as ApiApplicationViolationListDTOV2
from sonatype_iq_api_client.models.api_application_waiver_dto import ApiApplicationWaiverDTO as ApiApplicationWaiverDTO
from sonatype_iq_api_client.models.api_applied_license_overrides_dto import ApiAppliedLicenseOverridesDTO as ApiAppliedLicenseOverridesDTO
from sonatype_iq_api_client.models.api_artifactory_connection_dto import ApiArtifactoryConnectionDTO as ApiArtifactoryConnectionDTO
from sonatype_iq_api_client.models.api_artifactory_connection_status_request_dto import ApiArtifactoryConnectionStatusRequestDTO as ApiArtifactoryConnectionStatusRequestDTO
from sonatype_iq_api_client.models.api_artifactory_connection_status_response_dto import ApiArtifactoryConnectionStatusResponseDTO as ApiArtifactoryConnectionStatusResponseDTO
from sonatype_iq_api_client.models.api_auto_policy_waiver_dto import ApiAutoPolicyWaiverDTO as ApiAutoPolicyWaiverDTO
from sonatype_iq_api_client.models.api_auto_policy_waiver_exclusion_request_dto import ApiAutoPolicyWaiverExclusionRequestDTO as ApiAutoPolicyWaiverExclusionRequestDTO
from sonatype_iq_api_client.models.api_auto_policy_waiver_exclusion_response_dto import ApiAutoPolicyWaiverExclusionResponseDTO as ApiAutoPolicyWaiverExclusionResponseDTO
from sonatype_iq_api_client.models.api_auto_policy_waiver_status_dto import ApiAutoPolicyWaiverStatusDTO as ApiAutoPolicyWaiverStatusDTO
from sonatype_iq_api_client.models.api_bulk_waivers_dto import ApiBulkWaiversDTO as ApiBulkWaiversDTO
from sonatype_iq_api_client.models.api_component_change_action_dto import ApiComponentChangeActionDTO as ApiComponentChangeActionDTO
from sonatype_iq_api_client.models.api_component_dtov2 import ApiComponentDTOV2 as ApiComponentDTOV2
from sonatype_iq_api_client.models.api_component_details_dtov2 import ApiComponentDetailsDTOV2 as ApiComponentDetailsDTOV2
from sonatype_iq_api_client.models.api_component_details_request_dtov2 import ApiComponentDetailsRequestDTOV2 as ApiComponentDetailsRequestDTOV2
from sonatype_iq_api_client.models.api_component_details_result_dtov2 import ApiComponentDetailsResultDTOV2 as ApiComponentDetailsResultDTOV2
from sonatype_iq_api_client.models.api_component_evaluation_request_dtov2 import ApiComponentEvaluationRequestDTOV2 as ApiComponentEvaluationRequestDTOV2
from sonatype_iq_api_client.models.api_component_evaluation_result_dtov2 import ApiComponentEvaluationResultDTOV2 as ApiComponentEvaluationResultDTOV2
from sonatype_iq_api_client.models.api_component_evaluation_ticket_dtov2 import ApiComponentEvaluationTicketDTOV2 as ApiComponentEvaluationTicketDTOV2
from sonatype_iq_api_client.models.api_component_identifier_dtov2 import ApiComponentIdentifierDTOV2 as ApiComponentIdentifierDTOV2
from sonatype_iq_api_client.models.api_component_or_purl_identifier_dtov2 import ApiComponentOrPurlIdentifierDTOV2 as ApiComponentOrPurlIdentifierDTOV2
from sonatype_iq_api_client.models.api_component_policy_violation_dto import ApiComponentPolicyViolationDTO as ApiComponentPolicyViolationDTO
from sonatype_iq_api_client.models.api_component_policy_violation_list_dtov2 import ApiComponentPolicyViolationListDTOV2 as ApiComponentPolicyViolationListDTOV2
from sonatype_iq_api_client.models.api_component_policy_waivers_dto import ApiComponentPolicyWaiversDTO as ApiComponentPolicyWaiversDTO
from sonatype_iq_api_client.models.api_component_project_data_dto import ApiComponentProjectDataDTO as ApiComponentProjectDataDTO
from sonatype_iq_api_client.models.api_component_project_metadata_dto import ApiComponentProjectMetadataDTO as ApiComponentProjectMetadataDTO
from sonatype_iq_api_client.models.api_component_project_scm_dto import ApiComponentProjectScmDTO as ApiComponentProjectScmDTO
from sonatype_iq_api_client.models.api_component_project_scm_details_dto import ApiComponentProjectScmDetailsDTO as ApiComponentProjectScmDetailsDTO
from sonatype_iq_api_client.models.api_component_project_scm_metadata_dto import ApiComponentProjectScmMetadataDTO as ApiComponentProjectScmMetadataDTO
from sonatype_iq_api_client.models.api_component_released_from_quarantine_dto import ApiComponentReleasedFromQuarantineDTO as ApiComponentReleasedFromQuarantineDTO
from sonatype_iq_api_client.models.api_component_remediation_value_dto import ApiComponentRemediationValueDTO as ApiComponentRemediationValueDTO
from sonatype_iq_api_client.models.api_component_transitive_policy_violations_dto import ApiComponentTransitivePolicyViolationsDTO as ApiComponentTransitivePolicyViolationsDTO
from sonatype_iq_api_client.models.api_component_waivers_dto import ApiComponentWaiversDTO as ApiComponentWaiversDTO
from sonatype_iq_api_client.models.api_components_in_quarantine_dto import ApiComponentsInQuarantineDTO as ApiComponentsInQuarantineDTO
from sonatype_iq_api_client.models.api_composite_source_control_dto import ApiCompositeSourceControlDTO as ApiCompositeSourceControlDTO
from sonatype_iq_api_client.models.api_composite_value_dto_boolean import ApiCompositeValueDTOBoolean as ApiCompositeValueDTOBoolean
from sonatype_iq_api_client.models.api_composite_value_dto_integer import ApiCompositeValueDTOInteger as ApiCompositeValueDTOInteger
from sonatype_iq_api_client.models.api_composite_value_dto_string import ApiCompositeValueDTOString as ApiCompositeValueDTOString
from sonatype_iq_api_client.models.api_condition_fact_reason_dto import ApiConditionFactReasonDTO as ApiConditionFactReasonDTO
from sonatype_iq_api_client.models.api_constraint_fact_dto import ApiConstraintFactDTO as ApiConstraintFactDTO
from sonatype_iq_api_client.models.api_constraint_violation_dto import ApiConstraintViolationDTO as ApiConstraintViolationDTO
from sonatype_iq_api_client.models.api_constraint_violation_reason_dto import ApiConstraintViolationReasonDTO as ApiConstraintViolationReasonDTO
from sonatype_iq_api_client.models.api_container_image_waiver_dto import ApiContainerImageWaiverDTO as ApiContainerImageWaiverDTO
from sonatype_iq_api_client.models.api_cross_stage_violation_dtov2 import ApiCrossStageViolationDTOV2 as ApiCrossStageViolationDTOV2
from sonatype_iq_api_client.models.api_crowd_configuration_dto import ApiCrowdConfigurationDTO as ApiCrowdConfigurationDTO
from sonatype_iq_api_client.models.api_data_retention_policies_dto import ApiDataRetentionPoliciesDTO as ApiDataRetentionPoliciesDTO
from sonatype_iq_api_client.models.api_dependency_data_dto import ApiDependencyDataDTO as ApiDependencyDataDTO
from sonatype_iq_api_client.models.api_dependency_tree_node_dto import ApiDependencyTreeNodeDTO as ApiDependencyTreeNodeDTO
from sonatype_iq_api_client.models.api_dependency_tree_response_dto import ApiDependencyTreeResponseDTO as ApiDependencyTreeResponseDTO
from sonatype_iq_api_client.models.api_enhanced_policy_violation_dtov2 import ApiEnhancedPolicyViolationDTOV2 as ApiEnhancedPolicyViolationDTOV2
from sonatype_iq_api_client.models.api_evaluation_result_counter_dto import ApiEvaluationResultCounterDTO as ApiEvaluationResultCounterDTO
from sonatype_iq_api_client.models.api_firewall_component_dto import ApiFirewallComponentDTO as ApiFirewallComponentDTO
from sonatype_iq_api_client.models.api_firewall_component_dto_result import ApiFirewallComponentDTOResult as ApiFirewallComponentDTOResult
from sonatype_iq_api_client.models.api_firewall_metrics_result_dto import ApiFirewallMetricsResultDTO as ApiFirewallMetricsResultDTO
from sonatype_iq_api_client.models.api_firewall_quarantine_summary_dto import ApiFirewallQuarantineSummaryDTO as ApiFirewallQuarantineSummaryDTO
from sonatype_iq_api_client.models.api_firewall_quarantined_component_dto import ApiFirewallQuarantinedComponentDto as ApiFirewallQuarantinedComponentDto
from sonatype_iq_api_client.models.api_firewall_quarantined_component_dto_result import ApiFirewallQuarantinedComponentDtoResult as ApiFirewallQuarantinedComponentDtoResult
from sonatype_iq_api_client.models.api_firewall_release_quarantine_config_dto import ApiFirewallReleaseQuarantineConfigDTO as ApiFirewallReleaseQuarantineConfigDTO
from sonatype_iq_api_client.models.api_firewall_release_quarantine_summary_dto import ApiFirewallReleaseQuarantineSummaryDTO as ApiFirewallReleaseQuarantineSummaryDTO
from sonatype_iq_api_client.models.api_global_information_dtov2 import ApiGlobalInformationDTOV2 as ApiGlobalInformationDTOV2
from sonatype_iq_api_client.models.api_hash_component_identifier_dto import ApiHashComponentIdentifierDTO as ApiHashComponentIdentifierDTO
from sonatype_iq_api_client.models.api_hash_component_identifiers_dto import ApiHashComponentIdentifiersDTO as ApiHashComponentIdentifiersDTO
from sonatype_iq_api_client.models.api_jira_configuration_dto import ApiJiraConfigurationDTO as ApiJiraConfigurationDTO
from sonatype_iq_api_client.models.api_label_dto import ApiLabelDTO as ApiLabelDTO
from sonatype_iq_api_client.models.api_license_dto import ApiLicenseDTO as ApiLicenseDTO
from sonatype_iq_api_client.models.api_license_data_dto import ApiLicenseDataDTO as ApiLicenseDataDTO
from sonatype_iq_api_client.models.api_license_data_dtov2 import ApiLicenseDataDTOV2 as ApiLicenseDataDTOV2
from sonatype_iq_api_client.models.api_license_legal_application_report_dto import ApiLicenseLegalApplicationReportDTO as ApiLicenseLegalApplicationReportDTO
from sonatype_iq_api_client.models.api_license_legal_component_dto import ApiLicenseLegalComponentDTO as ApiLicenseLegalComponentDTO
from sonatype_iq_api_client.models.api_license_legal_component_report_dto import ApiLicenseLegalComponentReportDTO as ApiLicenseLegalComponentReportDTO
from sonatype_iq_api_client.models.api_license_legal_copyright_dto import ApiLicenseLegalCopyrightDTO as ApiLicenseLegalCopyrightDTO
from sonatype_iq_api_client.models.api_license_legal_data_dto import ApiLicenseLegalDataDTO as ApiLicenseLegalDataDTO
from sonatype_iq_api_client.models.api_license_legal_file_dto import ApiLicenseLegalFileDTO as ApiLicenseLegalFileDTO
from sonatype_iq_api_client.models.api_license_legal_metadata_dto import ApiLicenseLegalMetadataDTO as ApiLicenseLegalMetadataDTO
from sonatype_iq_api_client.models.api_license_legal_obligation_dto import ApiLicenseLegalObligationDTO as ApiLicenseLegalObligationDTO
from sonatype_iq_api_client.models.api_license_legal_stage_scan_dto import ApiLicenseLegalStageScanDTO as ApiLicenseLegalStageScanDTO
from sonatype_iq_api_client.models.api_license_override_dto import ApiLicenseOverrideDTO as ApiLicenseOverrideDTO
from sonatype_iq_api_client.models.api_license_threat_dtov2 import ApiLicenseThreatDTOV2 as ApiLicenseThreatDTOV2
from sonatype_iq_api_client.models.api_licensed_solution_dto import ApiLicensedSolutionDTO as ApiLicensedSolutionDTO
from sonatype_iq_api_client.models.api_mail_configuration_dto import ApiMailConfigurationDTO as ApiMailConfigurationDTO
from sonatype_iq_api_client.models.api_malware_component_evaluation_request import ApiMalwareComponentEvaluationRequest as ApiMalwareComponentEvaluationRequest
from sonatype_iq_api_client.models.api_malware_component_evaluation_request_list import ApiMalwareComponentEvaluationRequestList as ApiMalwareComponentEvaluationRequestList
from sonatype_iq_api_client.models.api_match_state_summary_dtov2 import ApiMatchStateSummaryDTOV2 as ApiMatchStateSummaryDTOV2
from sonatype_iq_api_client.models.api_member_dto import ApiMemberDTO as ApiMemberDTO
from sonatype_iq_api_client.models.api_metrics_reporting_aggregation_dtov2 import ApiMetricsReportingAggregationDTOV2 as ApiMetricsReportingAggregationDTOV2
from sonatype_iq_api_client.models.api_metrics_reporting_dtov2 import ApiMetricsReportingDTOV2 as ApiMetricsReportingDTOV2
from sonatype_iq_api_client.models.api_metrics_reporting_query_dtov2 import ApiMetricsReportingQueryDTOV2 as ApiMetricsReportingQueryDTOV2
from sonatype_iq_api_client.models.api_move_application_response_dtov2 import ApiMoveApplicationResponseDTOV2 as ApiMoveApplicationResponseDTOV2
from sonatype_iq_api_client.models.api_organization_dto import ApiOrganizationDTO as ApiOrganizationDTO
from sonatype_iq_api_client.models.api_organization_list_dto import ApiOrganizationListDTO as ApiOrganizationListDTO
from sonatype_iq_api_client.models.api_owner_artifactory_connection_dto import ApiOwnerArtifactoryConnectionDTO as ApiOwnerArtifactoryConnectionDTO
from sonatype_iq_api_client.models.api_owner_dto import ApiOwnerDTO as ApiOwnerDTO
from sonatype_iq_api_client.models.api_page_result_prioritized_component import ApiPageResultPrioritizedComponent as ApiPageResultPrioritizedComponent
from sonatype_iq_api_client.models.api_policy_dto import ApiPolicyDTO as ApiPolicyDTO
from sonatype_iq_api_client.models.api_policy_list_dto import ApiPolicyListDTO as ApiPolicyListDTO
from sonatype_iq_api_client.models.api_policy_violation_dtov2 import ApiPolicyViolationDTOV2 as ApiPolicyViolationDTOV2
from sonatype_iq_api_client.models.api_policy_violation_diff_dto import ApiPolicyViolationDiffDTO as ApiPolicyViolationDiffDTO
from sonatype_iq_api_client.models.api_policy_violation_for_diff_dto import ApiPolicyViolationForDiffDTO as ApiPolicyViolationForDiffDTO
from sonatype_iq_api_client.models.api_policy_violation_stage_dto import ApiPolicyViolationStageDTO as ApiPolicyViolationStageDTO
from sonatype_iq_api_client.models.api_policy_waiver_dto import ApiPolicyWaiverDTO as ApiPolicyWaiverDTO
from sonatype_iq_api_client.models.api_policy_waiver_reason_dto import ApiPolicyWaiverReasonDTO as ApiPolicyWaiverReasonDTO
from sonatype_iq_api_client.models.api_policy_waiver_request_dto import ApiPolicyWaiverRequestDTO as ApiPolicyWaiverRequestDTO
from sonatype_iq_api_client.models.api_policy_waiver_request_options_dto import ApiPolicyWaiverRequestOptionsDTO as ApiPolicyWaiverRequestOptionsDTO
from sonatype_iq_api_client.models.api_policy_waiver_request_review_dto import ApiPolicyWaiverRequestReviewDTO as ApiPolicyWaiverRequestReviewDTO
from sonatype_iq_api_client.models.api_policy_waiver_requests_applicable_to_violation_dto import ApiPolicyWaiverRequestsApplicableToViolationDTO as ApiPolicyWaiverRequestsApplicableToViolationDTO
from sonatype_iq_api_client.models.api_policy_waivers_applicable_to_violation_dto import ApiPolicyWaiversApplicableToViolationDTO as ApiPolicyWaiversApplicableToViolationDTO
from sonatype_iq_api_client.models.api_promote_scan_request_dtov2 import ApiPromoteScanRequestDTOV2 as ApiPromoteScanRequestDTOV2
from sonatype_iq_api_client.models.api_proxy_server_configuration_dto import ApiProxyServerConfigurationDTO as ApiProxyServerConfigurationDTO
from sonatype_iq_api_client.models.api_pull_request_result import ApiPullRequestResult as ApiPullRequestResult
from sonatype_iq_api_client.models.api_pull_request_results import ApiPullRequestResults as ApiPullRequestResults
from sonatype_iq_api_client.models.api_report_component_dtov2 import ApiReportComponentDTOV2 as ApiReportComponentDTOV2
from sonatype_iq_api_client.models.api_report_component_policy_violations_dtov2 import ApiReportComponentPolicyViolationsDTOV2 as ApiReportComponentPolicyViolationsDTOV2
from sonatype_iq_api_client.models.api_report_constraint_condition_dtov2 import ApiReportConstraintConditionDTOV2 as ApiReportConstraintConditionDTOV2
from sonatype_iq_api_client.models.api_report_constraint_violation_dtov2 import ApiReportConstraintViolationDTOV2 as ApiReportConstraintViolationDTOV2
from sonatype_iq_api_client.models.api_report_history_dto import ApiReportHistoryDTO as ApiReportHistoryDTO
from sonatype_iq_api_client.models.api_report_policy_data_dtov2 import ApiReportPolicyDataDTOV2 as ApiReportPolicyDataDTOV2
from sonatype_iq_api_client.models.api_report_policy_violation_dtov2 import ApiReportPolicyViolationDTOV2 as ApiReportPolicyViolationDTOV2
from sonatype_iq_api_client.models.api_report_raw_data_dtov2 import ApiReportRawDataDTOV2 as ApiReportRawDataDTOV2
from sonatype_iq_api_client.models.api_report_results_dto import ApiReportResultsDTO as ApiReportResultsDTO
from sonatype_iq_api_client.models.api_report_retention_policies_dto import ApiReportRetentionPoliciesDTO as ApiReportRetentionPoliciesDTO
from sonatype_iq_api_client.models.api_report_retention_policy_dto import ApiReportRetentionPolicyDTO as ApiReportRetentionPolicyDTO
from sonatype_iq_api_client.models.api_repository_component_dto import ApiRepositoryComponentDTO as ApiRepositoryComponentDTO
from sonatype_iq_api_client.models.api_repository_component_evaluation_request import ApiRepositoryComponentEvaluationRequest as ApiRepositoryComponentEvaluationRequest
from sonatype_iq_api_client.models.api_repository_component_evaluation_request_list import ApiRepositoryComponentEvaluationRequestList as ApiRepositoryComponentEvaluationRequestList
from sonatype_iq_api_client.models.api_repository_component_evaluation_result import ApiRepositoryComponentEvaluationResult as ApiRepositoryComponentEvaluationResult
from sonatype_iq_api_client.models.api_repository_component_evaluation_result_list import ApiRepositoryComponentEvaluationResultList as ApiRepositoryComponentEvaluationResultList
from sonatype_iq_api_client.models.api_repository_component_path import ApiRepositoryComponentPath as ApiRepositoryComponentPath
from sonatype_iq_api_client.models.api_repository_component_policy_violation_dto import ApiRepositoryComponentPolicyViolationDTO as ApiRepositoryComponentPolicyViolationDTO
from sonatype_iq_api_client.models.api_repository_components_in_quarantine_dto import ApiRepositoryComponentsInQuarantineDTO as ApiRepositoryComponentsInQuarantineDTO
from sonatype_iq_api_client.models.api_repository_container_dto import ApiRepositoryContainerDTO as ApiRepositoryContainerDTO
from sonatype_iq_api_client.models.api_repository_dto import ApiRepositoryDTO as ApiRepositoryDTO
from sonatype_iq_api_client.models.api_repository_list_dto import ApiRepositoryListDTO as ApiRepositoryListDTO
from sonatype_iq_api_client.models.api_repository_manager_dto import ApiRepositoryManagerDTO as ApiRepositoryManagerDTO
from sonatype_iq_api_client.models.api_repository_manager_list_dto import ApiRepositoryManagerListDTO as ApiRepositoryManagerListDTO
from sonatype_iq_api_client.models.api_repository_path_response_dto import ApiRepositoryPathResponseDTO as ApiRepositoryPathResponseDTO
from sonatype_iq_api_client.models.api_repository_path_versions import ApiRepositoryPathVersions as ApiRepositoryPathVersions
from sonatype_iq_api_client.models.api_repository_waiver_dto import ApiRepositoryWaiverDTO as ApiRepositoryWaiverDTO
from sonatype_iq_api_client.models.api_request_policy_waiver_dto import ApiRequestPolicyWaiverDTO as ApiRequestPolicyWaiverDTO
from sonatype_iq_api_client.models.api_reverse_proxy_authentication_configuration_dto import ApiReverseProxyAuthenticationConfigurationDTO as ApiReverseProxyAuthenticationConfigurationDTO
from sonatype_iq_api_client.models.api_role_dto import ApiRoleDTO as ApiRoleDTO
from sonatype_iq_api_client.models.api_role_list_dto import ApiRoleListDTO as ApiRoleListDTO
from sonatype_iq_api_client.models.api_role_member_mapping_dto import ApiRoleMemberMappingDTO as ApiRoleMemberMappingDTO
from sonatype_iq_api_client.models.api_role_member_mapping_list_dto import ApiRoleMemberMappingListDTO as ApiRoleMemberMappingListDTO
from sonatype_iq_api_client.models.api_saml_configuration_dto import ApiSamlConfigurationDTO as ApiSamlConfigurationDTO
from sonatype_iq_api_client.models.api_saml_configuration_response_dto import ApiSamlConfigurationResponseDTO as ApiSamlConfigurationResponseDTO
from sonatype_iq_api_client.models.api_search_criteria_dtov2 import ApiSearchCriteriaDTOV2 as ApiSearchCriteriaDTOV2
from sonatype_iq_api_client.models.api_search_result_dtov2 import ApiSearchResultDTOV2 as ApiSearchResultDTOV2
from sonatype_iq_api_client.models.api_search_results_dtov2 import ApiSearchResultsDTOV2 as ApiSearchResultsDTOV2
from sonatype_iq_api_client.models.api_security_data_dto import ApiSecurityDataDTO as ApiSecurityDataDTO
from sonatype_iq_api_client.models.api_security_issue_analysis_dto import ApiSecurityIssueAnalysisDTO as ApiSecurityIssueAnalysisDTO
from sonatype_iq_api_client.models.api_security_issue_dto import ApiSecurityIssueDTO as ApiSecurityIssueDTO
from sonatype_iq_api_client.models.api_security_vulnerability_override_dtov2 import ApiSecurityVulnerabilityOverrideDTOV2 as ApiSecurityVulnerabilityOverrideDTOV2
from sonatype_iq_api_client.models.api_security_vulnerability_override_response_dtov2 import ApiSecurityVulnerabilityOverrideResponseDTOV2 as ApiSecurityVulnerabilityOverrideResponseDTOV2
from sonatype_iq_api_client.models.api_source_control_configuration_dto import ApiSourceControlConfigurationDTO as ApiSourceControlConfigurationDTO
from sonatype_iq_api_client.models.api_source_control_dto import ApiSourceControlDTO as ApiSourceControlDTO
from sonatype_iq_api_client.models.api_source_control_evaluation_request_dto import ApiSourceControlEvaluationRequestDTO as ApiSourceControlEvaluationRequestDTO
from sonatype_iq_api_client.models.api_stage_policy_violation_component_dto import ApiStagePolicyViolationComponentDTO as ApiStagePolicyViolationComponentDTO
from sonatype_iq_api_client.models.api_stale_application_evaluation_dto import ApiStaleApplicationEvaluationDTO as ApiStaleApplicationEvaluationDTO
from sonatype_iq_api_client.models.api_stale_evaluation_stage_dto import ApiStaleEvaluationStageDTO as ApiStaleEvaluationStageDTO
from sonatype_iq_api_client.models.api_stale_evaluations_dto import ApiStaleEvaluationsDTO as ApiStaleEvaluationsDTO
from sonatype_iq_api_client.models.api_stale_repository_evaluation_dto import ApiStaleRepositoryEvaluationDTO as ApiStaleRepositoryEvaluationDTO
from sonatype_iq_api_client.models.api_stale_waiver_dto import ApiStaleWaiverDTO as ApiStaleWaiverDTO
from sonatype_iq_api_client.models.api_stale_waivers_response_dto import ApiStaleWaiversResponseDTO as ApiStaleWaiversResponseDTO
from sonatype_iq_api_client.models.api_status_dto import ApiStatusDTO as ApiStatusDTO
from sonatype_iq_api_client.models.api_success_metrics_retention_policy_dto import ApiSuccessMetricsRetentionPolicyDTO as ApiSuccessMetricsRetentionPolicyDTO
from sonatype_iq_api_client.models.api_suggested_version_change_option_dto import ApiSuggestedVersionChangeOptionDTO as ApiSuggestedVersionChangeOptionDTO
from sonatype_iq_api_client.models.api_tag_dto import ApiTagDTO as ApiTagDTO
from sonatype_iq_api_client.models.api_third_party_scan_result_dto import ApiThirdPartyScanResultDTO as ApiThirdPartyScanResultDTO
from sonatype_iq_api_client.models.api_third_party_scan_ticket_dto import ApiThirdPartyScanTicketDTO as ApiThirdPartyScanTicketDTO
from sonatype_iq_api_client.models.api_user_dto import ApiUserDTO as ApiUserDTO
from sonatype_iq_api_client.models.api_user_list_dto import ApiUserListDTO as ApiUserListDTO
from sonatype_iq_api_client.models.api_user_token_dto import ApiUserTokenDTO as ApiUserTokenDTO
from sonatype_iq_api_client.models.api_user_token_exists_dto import ApiUserTokenExistsDTO as ApiUserTokenExistsDTO
from sonatype_iq_api_client.models.api_version_change_option_dto import ApiVersionChangeOptionDTO as ApiVersionChangeOptionDTO
from sonatype_iq_api_client.models.api_waived_policy_violation_dto import ApiWaivedPolicyViolationDTO as ApiWaivedPolicyViolationDTO
from sonatype_iq_api_client.models.api_waiver_options_dto import ApiWaiverOptionsDTO as ApiWaiverOptionsDTO
from sonatype_iq_api_client.models.api_z_scaler_configuration_dto import ApiZScalerConfigurationDTO as ApiZScalerConfigurationDTO
from sonatype_iq_api_client.models.api_z_scaler_quota_dto import ApiZScalerQuotaDTO as ApiZScalerQuotaDTO
from sonatype_iq_api_client.models.applicable_context import ApplicableContext as ApplicableContext
from sonatype_iq_api_client.models.applicable_labels import ApplicableLabels as ApplicableLabels
from sonatype_iq_api_client.models.applicable_tags_dto import ApplicableTagsDTO as ApplicableTagsDTO
from sonatype_iq_api_client.models.application_tag import ApplicationTag as ApplicationTag
from sonatype_iq_api_client.models.application_tags_by_owner_dto import ApplicationTagsByOwnerDTO as ApplicationTagsByOwnerDTO
from sonatype_iq_api_client.models.applied_tags_dto import AppliedTagsDTO as AppliedTagsDTO
from sonatype_iq_api_client.models.attachment_text import AttachmentText as AttachmentText
from sonatype_iq_api_client.models.attribution_report_template_dto import AttributionReportTemplateDTO as AttributionReportTemplateDTO
from sonatype_iq_api_client.models.bulk_security_vulnerability_data_dto import BulkSecurityVulnerabilityDataDTO as BulkSecurityVulnerabilityDataDTO
from sonatype_iq_api_client.models.component_display_name import ComponentDisplayName as ComponentDisplayName
from sonatype_iq_api_client.models.component_display_name_part import ComponentDisplayNamePart as ComponentDisplayNamePart
from sonatype_iq_api_client.models.component_fact import ComponentFact as ComponentFact
from sonatype_iq_api_client.models.component_identifier import ComponentIdentifier as ComponentIdentifier
from sonatype_iq_api_client.models.component_locator import ComponentLocator as ComponentLocator
from sonatype_iq_api_client.models.component_obligation_attribution_dto import ComponentObligationAttributionDTO as ComponentObligationAttributionDTO
from sonatype_iq_api_client.models.condition_fact import ConditionFact as ConditionFact
from sonatype_iq_api_client.models.configuration_validation_result import ConfigurationValidationResult as ConfigurationValidationResult
from sonatype_iq_api_client.models.constraint_fact import ConstraintFact as ConstraintFact
from sonatype_iq_api_client.models.container_image_in_quarantine_data import ContainerImageInQuarantineData as ContainerImageInQuarantineData
from sonatype_iq_api_client.models.container_image_in_quarantine_data_result import ContainerImageInQuarantineDataResult as ContainerImageInQuarantineDataResult
from sonatype_iq_api_client.models.cpe_matching_configuration_request import CpeMatchingConfigurationRequest as CpeMatchingConfigurationRequest
from sonatype_iq_api_client.models.cwe_id import CweId as CweId
from sonatype_iq_api_client.models.cwe_id_dto import CweIdDTO as CweIdDTO
from sonatype_iq_api_client.models.development_prioritization_results import DevelopmentPrioritizationResults as DevelopmentPrioritizationResults
from sonatype_iq_api_client.models.epss_data import EpssData as EpssData
from sonatype_iq_api_client.models.get_suggested_remediation_for_component200_response import GetSuggestedRemediationForComponent200Response as GetSuggestedRemediationForComponent200Response
from sonatype_iq_api_client.models.grouping_by_dto import GroupingByDTO as GroupingByDTO
from sonatype_iq_api_client.models.import_sbom_request import ImportSbomRequest as ImportSbomRequest
from sonatype_iq_api_client.models.inner_source_data import InnerSourceData as InnerSourceData
from sonatype_iq_api_client.models.insert_or_update_saml_configuration_request import InsertOrUpdateSamlConfigurationRequest as InsertOrUpdateSamlConfigurationRequest
from sonatype_iq_api_client.models.install_license_request import InstallLicenseRequest as InstallLicenseRequest
from sonatype_iq_api_client.models.kev_data import KevData as KevData
from sonatype_iq_api_client.models.labels_by_owner import LabelsByOwner as LabelsByOwner
from sonatype_iq_api_client.models.legal_source_link_dto import LegalSourceLinkDTO as LegalSourceLinkDTO
from sonatype_iq_api_client.models.license_obligation_dto import LicenseObligationDTO as LicenseObligationDTO
from sonatype_iq_api_client.models.license_override import LicenseOverride as LicenseOverride
from sonatype_iq_api_client.models.license_override_by_owner import LicenseOverrideByOwner as LicenseOverrideByOwner
from sonatype_iq_api_client.models.license_threat_group_dto import LicenseThreatGroupDTO as LicenseThreatGroupDTO
from sonatype_iq_api_client.models.malware_category import MalwareCategory as MalwareCategory
from sonatype_iq_api_client.models.malware_defense_data import MalwareDefenseData as MalwareDefenseData
from sonatype_iq_api_client.models.malware_defense_response_list import MalwareDefenseResponseList as MalwareDefenseResponseList
from sonatype_iq_api_client.models.move_organization_response_dto import MoveOrganizationResponseDTO as MoveOrganizationResponseDTO
from sonatype_iq_api_client.models.policy_alert import PolicyAlert as PolicyAlert
from sonatype_iq_api_client.models.policy_container_waiver_data import PolicyContainerWaiverData as PolicyContainerWaiverData
from sonatype_iq_api_client.models.policy_container_waiver_data_result import PolicyContainerWaiverDataResult as PolicyContainerWaiverDataResult
from sonatype_iq_api_client.models.policy_evaluation_result import PolicyEvaluationResult as PolicyEvaluationResult
from sonatype_iq_api_client.models.policy_fact import PolicyFact as PolicyFact
from sonatype_iq_api_client.models.policy_owner import PolicyOwner as PolicyOwner
from sonatype_iq_api_client.models.policy_tag import PolicyTag as PolicyTag
from sonatype_iq_api_client.models.prioritized_component import PrioritizedComponent as PrioritizedComponent
from sonatype_iq_api_client.models.reference_link import ReferenceLink as ReferenceLink
from sonatype_iq_api_client.models.reference_link_dto import ReferenceLinkDTO as ReferenceLinkDTO
from sonatype_iq_api_client.models.root_cause import RootCause as RootCause
from sonatype_iq_api_client.models.root_cause_dto import RootCauseDTO as RootCauseDTO
from sonatype_iq_api_client.models.scm_user_mappings_dto import SCMUserMappingsDTO as SCMUserMappingsDTO
from sonatype_iq_api_client.models.scm_user_mappings_response_dto import SCMUserMappingsResponseDTO as SCMUserMappingsResponseDTO
from sonatype_iq_api_client.models.scm_user_matching_result_dto import SCMUserMatchingResultDTO as SCMUserMatchingResultDTO
from sonatype_iq_api_client.models.sbom_vulnerability_analysis_request import SbomVulnerabilityAnalysisRequest as SbomVulnerabilityAnalysisRequest
from sonatype_iq_api_client.models.search_result_dto import SearchResultDTO as SearchResultDTO
from sonatype_iq_api_client.models.search_result_item_dto import SearchResultItemDTO as SearchResultItemDTO
from sonatype_iq_api_client.models.security_vulnerability_custom_data import SecurityVulnerabilityCustomData as SecurityVulnerabilityCustomData
from sonatype_iq_api_client.models.security_vulnerability_custom_data_dto import SecurityVulnerabilityCustomDataDTO as SecurityVulnerabilityCustomDataDTO
from sonatype_iq_api_client.models.security_vulnerability_data import SecurityVulnerabilityData as SecurityVulnerabilityData
from sonatype_iq_api_client.models.security_vulnerability_data_dto import SecurityVulnerabilityDataDTO as SecurityVulnerabilityDataDTO
from sonatype_iq_api_client.models.security_vulnerability_severity import SecurityVulnerabilitySeverity as SecurityVulnerabilitySeverity
from sonatype_iq_api_client.models.security_vulnerability_severity_dto import SecurityVulnerabilitySeverityDTO as SecurityVulnerabilitySeverityDTO
from sonatype_iq_api_client.models.security_vulnerability_weakness import SecurityVulnerabilityWeakness as SecurityVulnerabilityWeakness
from sonatype_iq_api_client.models.security_vulnerability_weakness_dto import SecurityVulnerabilityWeaknessDTO as SecurityVulnerabilityWeaknessDTO
from sonatype_iq_api_client.models.stage_data import StageData as StageData
from sonatype_iq_api_client.models.swid import Swid as Swid
from sonatype_iq_api_client.models.system_config import SystemConfig as SystemConfig
from sonatype_iq_api_client.models.system_config_property import SystemConfigProperty as SystemConfigProperty
from sonatype_iq_api_client.models.tags_by_owner_dto import TagsByOwnerDTO as TagsByOwnerDTO
from sonatype_iq_api_client.models.trigger_reference import TriggerReference as TriggerReference
from sonatype_iq_api_client.models.user_mapping import UserMapping as UserMapping
from sonatype_iq_api_client.models.validation_error import ValidationError as ValidationError
from sonatype_iq_api_client.models.validation_result import ValidationResult as ValidationResult
from sonatype_iq_api_client.models.validation_warning import ValidationWarning as ValidationWarning
from sonatype_iq_api_client.models.vulnerability_analysis import VulnerabilityAnalysis as VulnerabilityAnalysis
from sonatype_iq_api_client.models.vulnerability_source import VulnerabilitySource as VulnerabilitySource
from sonatype_iq_api_client.models.vulnerability_source_dto import VulnerabilitySourceDTO as VulnerabilitySourceDTO




# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_repository_component_evaluation_result_list import ApiRepositoryComponentEvaluationResultList

class TestApiRepositoryComponentEvaluationResultList(unittest.TestCase):
    """ApiRepositoryComponentEvaluationResultList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiRepositoryComponentEvaluationResultList:
        """Test ApiRepositoryComponentEvaluationResultList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiRepositoryComponentEvaluationResultList`
        """
        model = ApiRepositoryComponentEvaluationResultList()
        if include_optional:
            return ApiRepositoryComponentEvaluationResultList(
                repository_id = '',
                repository_manager_id = '',
                repository_public_id = '',
                repository_type = '',
                results = [
                    sonatype_iq_api_client.models.api_repository_component_evaluation_result.ApiRepositoryComponentEvaluationResult(
                        catalog_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        component = sonatype_iq_api_client.models.api_repository_component_evaluation_request.ApiRepositoryComponentEvaluationRequest(
                            hash = '', 
                            package_url = '', 
                            pathname = '', ), 
                        policy_violations = [
                            sonatype_iq_api_client.models.api_policy_violation_dtov2.ApiPolicyViolationDTOV2(
                                constraint_violations = [
                                    sonatype_iq_api_client.models.api_constraint_violation_dto.ApiConstraintViolationDTO(
                                        constraint_id = '', 
                                        constraint_name = '', 
                                        reasons = [
                                            sonatype_iq_api_client.models.api_constraint_violation_reason_dto.ApiConstraintViolationReasonDTO(
                                                reason = '', 
                                                reference = sonatype_iq_api_client.models.trigger_reference.TriggerReference(
                                                    type = 'SECURITY_VULNERABILITY_REFID', 
                                                    value = '', ), )
                                            ], )
                                    ], 
                                fix_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                legacy_violation_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                open_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                policy_id = '', 
                                policy_name = '', 
                                policy_violation_id = '', 
                                threat_level = 56, 
                                waive_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                            ], 
                        quarantine_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        quarantined = True, )
                    ]
            )
        else:
            return ApiRepositoryComponentEvaluationResultList(
        )
        """

    def testApiRepositoryComponentEvaluationResultList(self):
        """Test ApiRepositoryComponentEvaluationResultList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_suggested_version_change_option_dto import ApiSuggestedVersionChangeOptionDTO

class TestApiSuggestedVersionChangeOptionDTO(unittest.TestCase):
    """ApiSuggestedVersionChangeOptionDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSuggestedVersionChangeOptionDTO:
        """Test ApiSuggestedVersionChangeOptionDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSuggestedVersionChangeOptionDTO`
        """
        model = ApiSuggestedVersionChangeOptionDTO()
        if include_optional:
            return ApiSuggestedVersionChangeOptionDTO(
                data = sonatype_iq_api_client.models.api_component_change_action_dto.ApiComponentChangeActionDTO(
                    component = sonatype_iq_api_client.models.api_component_dtov2.ApiComponentDTOV2(
                        component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                            coordinates = {
                                'key' : ''
                                }, 
                            format = '', ), 
                        display_name = '', 
                        hash = '', 
                        package_url = '', 
                        proprietary = True, 
                        sha256 = '', 
                        third_party = True, ), ),
                direct_dependency = True,
                direct_dependency_data = [
                    sonatype_iq_api_client.models.api_component_change_action_dto.ApiComponentChangeActionDTO(
                        component = sonatype_iq_api_client.models.api_component_dtov2.ApiComponentDTOV2(
                            component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                                coordinates = {
                                    'key' : ''
                                    }, 
                                format = '', ), 
                            display_name = '', 
                            hash = '', 
                            package_url = '', 
                            proprietary = True, 
                            sha256 = '', 
                            third_party = True, ), )
                    ],
                is_golden = True,
                type = 'next-no-violations'
            )
        else:
            return ApiSuggestedVersionChangeOptionDTO(
        )
        """

    def testApiSuggestedVersionChangeOptionDTO(self):
        """Test ApiSuggestedVersionChangeOptionDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.bulk_security_vulnerability_data_dto import BulkSecurityVulnerabilityDataDTO

class TestBulkSecurityVulnerabilityDataDTO(unittest.TestCase):
    """BulkSecurityVulnerabilityDataDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BulkSecurityVulnerabilityDataDTO:
        """Test BulkSecurityVulnerabilityDataDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BulkSecurityVulnerabilityDataDTO`
        """
        model = BulkSecurityVulnerabilityDataDTO()
        if include_optional:
            return BulkSecurityVulnerabilityDataDTO(
                vulnerabilities = {
                    'key' : sonatype_iq_api_client.models.security_vulnerability_data.SecurityVulnerabilityData(
                        advisories = [
                            sonatype_iq_api_client.models.reference_link.ReferenceLink(
                                reference_type = '', 
                                url = '', )
                            ], 
                        categories = [
                            ''
                            ], 
                        component_detection_markdown = '', 
                        component_explanation_markdown = '', 
                        component_recommendation_markdown = '', 
                        custom_data = sonatype_iq_api_client.models.security_vulnerability_custom_data.SecurityVulnerabilityCustomData(
                            cvss_severity = 1.337, 
                            cvss_vector = '', 
                            cwe_id = '', 
                            remediation = '', ), 
                        description = '', 
                        detection_markdown = '', 
                        detection_type = '', 
                        epss_data = sonatype_iq_api_client.models.epss_data.EpssData(
                            current_score = 1.337, ), 
                        explanation_markdown = '', 
                        identification_source = '', 
                        identifier = '', 
                        is_advanced_vulnerability_detection = True, 
                        kev_data = sonatype_iq_api_client.models.kev_data.KevData(
                            is_kev = True, ), 
                        main_severity = sonatype_iq_api_client.models.security_vulnerability_severity.SecurityVulnerabilitySeverity(
                            score = 1.337, 
                            source = '', 
                            source_label = '', 
                            vector = '', ), 
                        recommendation_markdown = '', 
                        research_type = 'FAST_TRACK', 
                        root_causes = [
                            sonatype_iq_api_client.models.root_cause.RootCause(
                                list_of_paths = [
                                    ''
                                    ], 
                                version_range = '', )
                            ], 
                        severity_scores = [
                            sonatype_iq_api_client.models.security_vulnerability_severity.SecurityVulnerabilitySeverity(
                                score = 1.337, 
                                source = '', 
                                source_label = '', 
                                vector = '', )
                            ], 
                        source = sonatype_iq_api_client.models.vulnerability_source.VulnerabilitySource(
                            long_name = '', 
                            short_name = '', ), 
                        vuln_ids = [
                            ''
                            ], 
                        vulnerability_link = '', 
                        vulnerable_version_ranges = [
                            ''
                            ], 
                        weakness = sonatype_iq_api_client.models.security_vulnerability_weakness.SecurityVulnerabilityWeakness(
                            cwe_ids = [
                                sonatype_iq_api_client.models.cwe_id.CweId(
                                    id = '', 
                                    uri = '', )
                                ], 
                            cwe_source = '', ), )
                    }
            )
        else:
            return BulkSecurityVulnerabilityDataDTO(
        )
        """

    def testBulkSecurityVulnerabilityDataDTO(self):
        """Test BulkSecurityVulnerabilityDataDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from sonatype_iq_api_client.models.attribution_report_template_dto import AttributionReportTemplateDTO

from sonatype_iq_api_client.api_client import ApiClient, RequestSerialized
from sonatype_iq_api_client.api_response import ApiResponse
from sonatype_iq_api_client.rest import RESTResponseType


class LicenseLegalMetadataTemplateApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def delete_attribution_report_template(
        self,
        id: Annotated[StrictStr, Field(description="Enter the template id for the template to be deleted.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """delete_attribution_report_template

        Use this method to delete an existing template.  Permissions required: Review Legal Obligations For Components Licenses for the root organization

        :param id: Enter the template id for the template to be deleted. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_attribution_report_template_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_attribution_report_template_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Enter the template id for the template to be deleted.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """delete_attribution_report_template

        Use this method to delete an existing template.  Permissions required: Review Legal Obligations For Components Licenses for the root organization

        :param id: Enter the template id for the template to be deleted. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_attribution_report_template_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_attribution_report_template_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Enter the template id for the template to be deleted.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """delete_attribution_report_template

        Use this method to delete an existing template.  Permissions required: Review Legal Obligations For Components Licenses for the root organization

        :param id: Enter the template id for the template to be deleted. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_attribution_report_template_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '204': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_attribution_report_template_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/api/v2/licenseLegalMetadata/report-template/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_all_attribution_report_templates(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[AttributionReportTemplateDTO]:
        """get_all_attribution_report_templates

        Use this method to retrieve templates for all reports.  Permissions required: Review Legal Obligations For Components Licenses for the root organization

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_all_attribution_report_templates_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[AttributionReportTemplateDTO]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_all_attribution_report_templates_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[AttributionReportTemplateDTO]]:
        """get_all_attribution_report_templates

        Use this method to retrieve templates for all reports.  Permissions required: Review Legal Obligations For Components Licenses for the root organization

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_all_attribution_report_templates_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[AttributionReportTemplateDTO]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_all_attribution_report_templates_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_all_attribution_report_templates

        Use this method to retrieve templates for all reports.  Permissions required: Review Legal Obligations For Components Licenses for the root organization

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_all_attribution_report_templates_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[AttributionReportTemplateDTO]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_all_attribution_report_templates_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/licenseLegalMetadata/report-template',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_attribution_report_template_by_id(
        self,
        id: Annotated[StrictStr, Field(description="Enter the templateId for the report.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AttributionReportTemplateDTO:
        """get_attribution_report_template_by_id

        Use this method to retrieve a template for license legal metadata.  Permissions required: Review Legal Obligations For Components Licenses for the root organization.

        :param id: Enter the templateId for the report. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_attribution_report_template_by_id_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AttributionReportTemplateDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_attribution_report_template_by_id_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Enter the templateId for the report.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AttributionReportTemplateDTO]:
        """get_attribution_report_template_by_id

        Use this method to retrieve a template for license legal metadata.  Permissions required: Review Legal Obligations For Components Licenses for the root organization.

        :param id: Enter the templateId for the report. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_attribution_report_template_by_id_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AttributionReportTemplateDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_attribution_report_template_by_id_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Enter the templateId for the report.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """get_attribution_report_template_by_id

        Use this method to retrieve a template for license legal metadata.  Permissions required: Review Legal Obligations For Components Licenses for the root organization.

        :param id: Enter the templateId for the report. (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_attribution_report_template_by_id_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AttributionReportTemplateDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_attribution_report_template_by_id_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/v2/licenseLegalMetadata/report-template/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def save_attribution_report_template(
        self,
        attribution_report_template_dto: Annotated[Optional[AttributionReportTemplateDTO], Field(description="Specify the details for the template as:<ul><li>`id` is the template id.</li><li>`templateName` indicates the name of the stored template.</li><li>`documentTitle` is the title that is displayed at the top of the report.</li><li>`header` is the text that will be displayed above the `documentTitle`.</li><li>`footer` is the text that will be displayed at the bottom of the report.<li><li>`includeTableOfContents` is `true` if a table of contents containing links to the components and their licenses will be added to the report.<li>`includeAppendix` is `true` if standard license text will be grouped in the report appendix.</li><li>`includeStandardLicenseTexts` is `true` if the standard license text will be displayed for components with no license files.</li><li>`includeSonatypeSpecialLicenses` is `true` if Sonatype Special Licenses (e.g. Generic-Copyleft-Clause, Generic-Liberal-Clause, See-License-Clause, Identity-Clause etc.) will be included in the report.</li><li>`includeInnerSource` is `true` if InnerSource components will be included in the report.</li></ul>")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> AttributionReportTemplateDTO:
        """save_attribution_report_template

        Use this method to create or update a template.  Permissions required: Review Legal Obligations For Components Licenses for the root organization

        :param attribution_report_template_dto: Specify the details for the template as:<ul><li>`id` is the template id.</li><li>`templateName` indicates the name of the stored template.</li><li>`documentTitle` is the title that is displayed at the top of the report.</li><li>`header` is the text that will be displayed above the `documentTitle`.</li><li>`footer` is the text that will be displayed at the bottom of the report.<li><li>`includeTableOfContents` is `true` if a table of contents containing links to the components and their licenses will be added to the report.<li>`includeAppendix` is `true` if standard license text will be grouped in the report appendix.</li><li>`includeStandardLicenseTexts` is `true` if the standard license text will be displayed for components with no license files.</li><li>`includeSonatypeSpecialLicenses` is `true` if Sonatype Special Licenses (e.g. Generic-Copyleft-Clause, Generic-Liberal-Clause, See-License-Clause, Identity-Clause etc.) will be included in the report.</li><li>`includeInnerSource` is `true` if InnerSource components will be included in the report.</li></ul>
        :type attribution_report_template_dto: AttributionReportTemplateDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._save_attribution_report_template_serialize(
            attribution_report_template_dto=attribution_report_template_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AttributionReportTemplateDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def save_attribution_report_template_with_http_info(
        self,
        attribution_report_template_dto: Annotated[Optional[AttributionReportTemplateDTO], Field(description="Specify the details for the template as:<ul><li>`id` is the template id.</li><li>`templateName` indicates the name of the stored template.</li><li>`documentTitle` is the title that is displayed at the top of the report.</li><li>`header` is the text that will be displayed above the `documentTitle`.</li><li>`footer` is the text that will be displayed at the bottom of the report.<li><li>`includeTableOfContents` is `true` if a table of contents containing links to the components and their licenses will be added to the report.<li>`includeAppendix` is `true` if standard license text will be grouped in the report appendix.</li><li>`includeStandardLicenseTexts` is `true` if the standard license text will be displayed for components with no license files.</li><li>`includeSonatypeSpecialLicenses` is `true` if Sonatype Special Licenses (e.g. Generic-Copyleft-Clause, Generic-Liberal-Clause, See-License-Clause, Identity-Clause etc.) will be included in the report.</li><li>`includeInnerSource` is `true` if InnerSource components will be included in the report.</li></ul>")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[AttributionReportTemplateDTO]:
        """save_attribution_report_template

        Use this method to create or update a template.  Permissions required: Review Legal Obligations For Components Licenses for the root organization

        :param attribution_report_template_dto: Specify the details for the template as:<ul><li>`id` is the template id.</li><li>`templateName` indicates the name of the stored template.</li><li>`documentTitle` is the title that is displayed at the top of the report.</li><li>`header` is the text that will be displayed above the `documentTitle`.</li><li>`footer` is the text that will be displayed at the bottom of the report.<li><li>`includeTableOfContents` is `true` if a table of contents containing links to the components and their licenses will be added to the report.<li>`includeAppendix` is `true` if standard license text will be grouped in the report appendix.</li><li>`includeStandardLicenseTexts` is `true` if the standard license text will be displayed for components with no license files.</li><li>`includeSonatypeSpecialLicenses` is `true` if Sonatype Special Licenses (e.g. Generic-Copyleft-Clause, Generic-Liberal-Clause, See-License-Clause, Identity-Clause etc.) will be included in the report.</li><li>`includeInnerSource` is `true` if InnerSource components will be included in the report.</li></ul>
        :type attribution_report_template_dto: AttributionReportTemplateDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._save_attribution_report_template_serialize(
            attribution_report_template_dto=attribution_report_template_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AttributionReportTemplateDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def save_attribution_report_template_without_preload_content(
        self,
        attribution_report_template_dto: Annotated[Optional[AttributionReportTemplateDTO], Field(description="Specify the details for the template as:<ul><li>`id` is the template id.</li><li>`templateName` indicates the name of the stored template.</li><li>`documentTitle` is the title that is displayed at the top of the report.</li><li>`header` is the text that will be displayed above the `documentTitle`.</li><li>`footer` is the text that will be displayed at the bottom of the report.<li><li>`includeTableOfContents` is `true` if a table of contents containing links to the components and their licenses will be added to the report.<li>`includeAppendix` is `true` if standard license text will be grouped in the report appendix.</li><li>`includeStandardLicenseTexts` is `true` if the standard license text will be displayed for components with no license files.</li><li>`includeSonatypeSpecialLicenses` is `true` if Sonatype Special Licenses (e.g. Generic-Copyleft-Clause, Generic-Liberal-Clause, See-License-Clause, Identity-Clause etc.) will be included in the report.</li><li>`includeInnerSource` is `true` if InnerSource components will be included in the report.</li></ul>")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """save_attribution_report_template

        Use this method to create or update a template.  Permissions required: Review Legal Obligations For Components Licenses for the root organization

        :param attribution_report_template_dto: Specify the details for the template as:<ul><li>`id` is the template id.</li><li>`templateName` indicates the name of the stored template.</li><li>`documentTitle` is the title that is displayed at the top of the report.</li><li>`header` is the text that will be displayed above the `documentTitle`.</li><li>`footer` is the text that will be displayed at the bottom of the report.<li><li>`includeTableOfContents` is `true` if a table of contents containing links to the components and their licenses will be added to the report.<li>`includeAppendix` is `true` if standard license text will be grouped in the report appendix.</li><li>`includeStandardLicenseTexts` is `true` if the standard license text will be displayed for components with no license files.</li><li>`includeSonatypeSpecialLicenses` is `true` if Sonatype Special Licenses (e.g. Generic-Copyleft-Clause, Generic-Liberal-Clause, See-License-Clause, Identity-Clause etc.) will be included in the report.</li><li>`includeInnerSource` is `true` if InnerSource components will be included in the report.</li></ul>
        :type attribution_report_template_dto: AttributionReportTemplateDTO
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._save_attribution_report_template_serialize(
            attribution_report_template_dto=attribution_report_template_dto,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AttributionReportTemplateDTO",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _save_attribution_report_template_serialize(
        self,
        attribution_report_template_dto,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if attribution_report_template_dto is not None:
            _body_params = attribution_report_template_dto


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'BasicAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/v2/licenseLegalMetadata/report-template',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.source_control_api import SourceControlApi


class TestSourceControlApi(unittest.TestCase):
    """SourceControlApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SourceControlApi()

    def tearDown(self) -> None:
        pass

    def test_add_source_control(self) -> None:
        """Test case for add_source_control

        """
        pass

    def test_add_user_mappings(self) -> None:
        """Test case for add_user_mappings

        """
        pass

    def test_automatic_role_assignment(self) -> None:
        """Test case for automatic_role_assignment

        """
        pass

    def test_delete_source_control(self) -> None:
        """Test case for delete_source_control

        """
        pass

    def test_delete_user_mappings(self) -> None:
        """Test case for delete_user_mappings

        """
        pass

    def test_get_source_control1(self) -> None:
        """Test case for get_source_control1

        """
        pass

    def test_get_user_mappings_by_owner(self) -> None:
        """Test case for get_user_mappings_by_owner

        """
        pass

    def test_update_source_control(self) -> None:
        """Test case for update_source_control

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.user_tokens_api import UserTokensApi


class TestUserTokensApi(unittest.TestCase):
    """UserTokensApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UserTokensApi()

    def tearDown(self) -> None:
        pass

    def test_create_user_token(self) -> None:
        """Test case for create_user_token

        """
        pass

    def test_delete_current_user_token(self) -> None:
        """Test case for delete_current_user_token

        """
        pass

    def test_delete_user_token_by_user_code(self) -> None:
        """Test case for delete_user_token_by_user_code

        """
        pass

    def test_get_user_token_by_username_and_realm_id(self) -> None:
        """Test case for get_user_token_by_username_and_realm_id

        """
        pass

    def test_get_user_token_exists_for_current_user(self) -> None:
        """Test case for get_user_token_exists_for_current_user

        """
        pass

    def test_get_user_tokens_by_created_between_and_realm_id(self) -> None:
        """Test case for get_user_tokens_by_created_between_and_realm_id

        """
        pass

    def test_purge_user_tokens(self) -> None:
        """Test case for purge_user_tokens

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ApiSourceControlDTO(BaseModel):
    """
    ApiSourceControlDTO
    """ # noqa: E501
    base_branch: Optional[StrictStr] = Field(default=None, alias="baseBranch")
    close_pr_after_days: Optional[StrictInt] = Field(default=None, alias="closePrAfterDays")
    close_pr_after_days_open_enabled: Optional[StrictBool] = Field(default=None, alias="closePrAfterDaysOpenEnabled")
    close_pr_on_failed_checks_enabled: Optional[StrictBool] = Field(default=None, alias="closePrOnFailedChecksEnabled")
    commit_status_enabled: Optional[StrictBool] = Field(default=None, alias="commitStatusEnabled")
    enable_pull_requests: Optional[StrictBool] = Field(default=None, alias="enablePullRequests")
    enable_status_checks: Optional[StrictBool] = Field(default=None, alias="enableStatusChecks")
    id: Optional[StrictStr] = None
    inner_source_automated_updates_enabled: Optional[StrictBool] = Field(default=None, alias="innerSourceAutomatedUpdatesEnabled")
    manual_pull_requests_enabled: Optional[StrictBool] = Field(default=None, alias="manualPullRequestsEnabled")
    owner_id: Optional[StrictStr] = Field(default=None, alias="ownerId")
    provider: Optional[StrictStr] = None
    pull_request_commenting_enabled: Optional[StrictBool] = Field(default=None, alias="pullRequestCommentingEnabled")
    remediation_pull_requests_enabled: Optional[StrictBool] = Field(default=None, alias="remediationPullRequestsEnabled")
    repository_url: Optional[StrictStr] = Field(default=None, alias="repositoryUrl")
    source_control_evaluations_enabled: Optional[StrictBool] = Field(default=None, alias="sourceControlEvaluationsEnabled")
    source_control_scan_target: Optional[StrictStr] = Field(default=None, alias="sourceControlScanTarget")
    ssh_enabled: Optional[StrictBool] = Field(default=None, alias="sshEnabled")
    status_checks_enabled: Optional[StrictBool] = Field(default=None, alias="statusChecksEnabled")
    token: Optional[StrictStr] = None
    username: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["baseBranch", "closePrAfterDays", "closePrAfterDaysOpenEnabled", "closePrOnFailedChecksEnabled", "commitStatusEnabled", "enablePullRequests", "enableStatusChecks", "id", "innerSourceAutomatedUpdatesEnabled", "manualPullRequestsEnabled", "ownerId", "provider", "pullRequestCommentingEnabled", "remediationPullRequestsEnabled", "repositoryUrl", "sourceControlEvaluationsEnabled", "sourceControlScanTarget", "sshEnabled", "statusChecksEnabled", "token", "username"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ApiSourceControlDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ApiSourceControlDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "baseBranch": obj.get("baseBranch"),
            "closePrAfterDays": obj.get("closePrAfterDays"),
            "closePrAfterDaysOpenEnabled": obj.get("closePrAfterDaysOpenEnabled"),
            "closePrOnFailedChecksEnabled": obj.get("closePrOnFailedChecksEnabled"),
            "commitStatusEnabled": obj.get("commitStatusEnabled"),
            "enablePullRequests": obj.get("enablePullRequests"),
            "enableStatusChecks": obj.get("enableStatusChecks"),
            "id": obj.get("id"),
            "innerSourceAutomatedUpdatesEnabled": obj.get("innerSourceAutomatedUpdatesEnabled"),
            "manualPullRequestsEnabled": obj.get("manualPullRequestsEnabled"),
            "ownerId": obj.get("ownerId"),
            "provider": obj.get("provider"),
            "pullRequestCommentingEnabled": obj.get("pullRequestCommentingEnabled"),
            "remediationPullRequestsEnabled": obj.get("remediationPullRequestsEnabled"),
            "repositoryUrl": obj.get("repositoryUrl"),
            "sourceControlEvaluationsEnabled": obj.get("sourceControlEvaluationsEnabled"),
            "sourceControlScanTarget": obj.get("sourceControlScanTarget"),
            "sshEnabled": obj.get("sshEnabled"),
            "statusChecksEnabled": obj.get("statusChecksEnabled"),
            "token": obj.get("token"),
            "username": obj.get("username")
        })
        return _obj





# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_hash_component_identifier_dto import ApiHashComponentIdentifierDTO

class TestApiHashComponentIdentifierDTO(unittest.TestCase):
    """ApiHashComponentIdentifierDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiHashComponentIdentifierDTO:
        """Test ApiHashComponentIdentifierDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiHashComponentIdentifierDTO`
        """
        model = ApiHashComponentIdentifierDTO()
        if include_optional:
            return ApiHashComponentIdentifierDTO(
                claimer_id = '',
                claimer_name = '',
                comment = '',
                component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                    coordinates = {
                        'key' : ''
                        }, 
                    format = '', ),
                create_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                hash = '',
                package_url = ''
            )
        else:
            return ApiHashComponentIdentifierDTO(
        )
        """

    def testApiHashComponentIdentifierDTO(self):
        """Test ApiHashComponentIdentifierDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_security_vulnerability_override_response_dtov2 import ApiSecurityVulnerabilityOverrideResponseDTOV2

class TestApiSecurityVulnerabilityOverrideResponseDTOV2(unittest.TestCase):
    """ApiSecurityVulnerabilityOverrideResponseDTOV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiSecurityVulnerabilityOverrideResponseDTOV2:
        """Test ApiSecurityVulnerabilityOverrideResponseDTOV2
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiSecurityVulnerabilityOverrideResponseDTOV2`
        """
        model = ApiSecurityVulnerabilityOverrideResponseDTOV2()
        if include_optional:
            return ApiSecurityVulnerabilityOverrideResponseDTOV2(
                security_overrides = [
                    sonatype_iq_api_client.models.api_security_vulnerability_override_dtov2.ApiSecurityVulnerabilityOverrideDTOV2(
                        comment = '', 
                        currently_affected_components = [
                            sonatype_iq_api_client.models.api_component_dtov2.ApiComponentDTOV2(
                                component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                                    coordinates = {
                                        'key' : ''
                                        }, 
                                    format = '', ), 
                                display_name = '', 
                                hash = '', 
                                package_url = '', 
                                proprietary = True, 
                                sha256 = '', 
                                third_party = True, )
                            ], 
                        hash = '', 
                        owner = sonatype_iq_api_client.models.api_owner_dto.ApiOwnerDTO(
                            owner_id = '', 
                            owner_name = '', 
                            owner_public_id = '', 
                            owner_type = '', ), 
                        reference_id = '', 
                        security_override_id = '', 
                        status = '', )
                    ]
            )
        else:
            return ApiSecurityVulnerabilityOverrideResponseDTOV2(
        )
        """

    def testApiSecurityVulnerabilityOverrideResponseDTOV2(self):
        """Test ApiSecurityVulnerabilityOverrideResponseDTOV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.security_vulnerability_data_dto import SecurityVulnerabilityDataDTO

class TestSecurityVulnerabilityDataDTO(unittest.TestCase):
    """SecurityVulnerabilityDataDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SecurityVulnerabilityDataDTO:
        """Test SecurityVulnerabilityDataDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SecurityVulnerabilityDataDTO`
        """
        model = SecurityVulnerabilityDataDTO()
        if include_optional:
            return SecurityVulnerabilityDataDTO(
                advisories = [
                    sonatype_iq_api_client.models.reference_link_dto.ReferenceLinkDTO(
                        reference_type = '', 
                        url = '', )
                    ],
                categories = [
                    ''
                    ],
                component_detection_markdown = '',
                component_explanation_markdown = '',
                component_recommendation_markdown = '',
                custom_data = sonatype_iq_api_client.models.security_vulnerability_custom_data_dto.SecurityVulnerabilityCustomDataDTO(
                    cvss_severity = 1.337, 
                    cvss_vector = '', 
                    cwe_id = '', 
                    remediation = '', ),
                description = '',
                detection_markdown = '',
                detection_type = '',
                epss_data = sonatype_iq_api_client.models.epss_data.EpssData(
                    current_score = 1.337, ),
                explanation_markdown = '',
                identification_source = '',
                identifier = '',
                is_advanced_vulnerability_detection = True,
                kev_data = sonatype_iq_api_client.models.kev_data.KevData(
                    is_kev = True, ),
                main_severity = sonatype_iq_api_client.models.security_vulnerability_severity_dto.SecurityVulnerabilitySeverityDTO(
                    score = 1.337, 
                    source = '', 
                    source_label = '', 
                    vector = '', ),
                recommendation_markdown = '',
                research_type = 'FAST_TRACK',
                root_causes = [
                    sonatype_iq_api_client.models.root_cause_dto.RootCauseDTO(
                        list_of_paths = [
                            ''
                            ], 
                        version_range = '', )
                    ],
                severity_scores = [
                    sonatype_iq_api_client.models.security_vulnerability_severity_dto.SecurityVulnerabilitySeverityDTO(
                        score = 1.337, 
                        source = '', 
                        source_label = '', 
                        vector = '', )
                    ],
                source = sonatype_iq_api_client.models.vulnerability_source_dto.VulnerabilitySourceDTO(
                    long_name = '', 
                    short_name = '', ),
                vuln_ids = [
                    ''
                    ],
                vulnerability_link = '',
                vulnerable_version_ranges = [
                    ''
                    ],
                weakness = sonatype_iq_api_client.models.security_vulnerability_weakness_dto.SecurityVulnerabilityWeaknessDTO(
                    cwe_ids = [
                        sonatype_iq_api_client.models.cwe_id_dto.CweIdDTO(
                            id = '', 
                            uri = '', )
                        ], 
                    cwe_source = '', )
            )
        else:
            return SecurityVulnerabilityDataDTO(
        )
        """

    def testSecurityVulnerabilityDataDTO(self):
        """Test SecurityVulnerabilityDataDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.firewall_api import FirewallApi


class TestFirewallApi(unittest.TestCase):
    """FirewallApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FirewallApi()

    def tearDown(self) -> None:
        pass

    def test_add_proprietary_component_names(self) -> None:
        """Test case for add_proprietary_component_names

        """
        pass

    def test_add_repository_manager(self) -> None:
        """Test case for add_repository_manager

        """
        pass

    def test_add_waiver(self) -> None:
        """Test case for add_waiver

        """
        pass

    def test_configure_repositories(self) -> None:
        """Test case for configure_repositories

        """
        pass

    def test_delete_container_image_policy_waiver(self) -> None:
        """Test case for delete_container_image_policy_waiver

        """
        pass

    def test_delete_repository_manager(self) -> None:
        """Test case for delete_repository_manager

        """
        pass

    def test_evaluate_components1(self) -> None:
        """Test case for evaluate_components1

        """
        pass

    def test_evaluate_malware(self) -> None:
        """Test case for evaluate_malware

        """
        pass

    def test_get_configured_repositories(self) -> None:
        """Test case for get_configured_repositories

        """
        pass

    def test_get_container_images_in_quarantine(self) -> None:
        """Test case for get_container_images_in_quarantine

        """
        pass

    def test_get_firewall_auto_unquarantine_config(self) -> None:
        """Test case for get_firewall_auto_unquarantine_config

        """
        pass

    def test_get_firewall_metrics(self) -> None:
        """Test case for get_firewall_metrics

        """
        pass

    def test_get_firewall_unquarantine_summary(self) -> None:
        """Test case for get_firewall_unquarantine_summary

        """
        pass

    def test_get_malware_defense_metrics(self) -> None:
        """Test case for get_malware_defense_metrics

        """
        pass

    def test_get_quarantine_list(self) -> None:
        """Test case for get_quarantine_list

        """
        pass

    def test_get_quarantine_summary(self) -> None:
        """Test case for get_quarantine_summary

        """
        pass

    def test_get_quarantined_component_view_anonymous_access(self) -> None:
        """Test case for get_quarantined_component_view_anonymous_access

        """
        pass

    def test_get_repository_container(self) -> None:
        """Test case for get_repository_container

        """
        pass

    def test_get_repository_manager(self) -> None:
        """Test case for get_repository_manager

        """
        pass

    def test_get_repository_managers(self) -> None:
        """Test case for get_repository_managers

        """
        pass

    def test_get_unquarantine_list(self) -> None:
        """Test case for get_unquarantine_list

        """
        pass

    def test_get_waivers(self) -> None:
        """Test case for get_waivers

        """
        pass

    def test_remove_proprietary_component_names(self) -> None:
        """Test case for remove_proprietary_component_names

        """
        pass

    def test_set_firewall_auto_unquarantine_config(self) -> None:
        """Test case for set_firewall_auto_unquarantine_config

        """
        pass

    def test_set_quarantined_component_view_anonymous_access(self) -> None:
        """Test case for set_quarantined_component_view_anonymous_access

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.api.application_categories_api import ApplicationCategoriesApi


class TestApplicationCategoriesApi(unittest.TestCase):
    """ApplicationCategoriesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ApplicationCategoriesApi()

    def tearDown(self) -> None:
        pass

    def test_add_tag(self) -> None:
        """Test case for add_tag

        """
        pass

    def test_delete_tag(self) -> None:
        """Test case for delete_tag

        """
        pass

    def test_get_applicable_tags(self) -> None:
        """Test case for get_applicable_tags

        """
        pass

    def test_get_applicable_tags_by_application_public_id(self) -> None:
        """Test case for get_applicable_tags_by_application_public_id

        """
        pass

    def test_get_application_applicable_tags(self) -> None:
        """Test case for get_application_applicable_tags

        """
        pass

    def test_get_applied_policy_tags(self) -> None:
        """Test case for get_applied_policy_tags

        """
        pass

    def test_get_applied_tags(self) -> None:
        """Test case for get_applied_tags

        """
        pass

    def test_get_tags(self) -> None:
        """Test case for get_tags

        """
        pass

    def test_get_tags_used_by_applications(self) -> None:
        """Test case for get_tags_used_by_applications

        """
        pass

    def test_update_tag(self) -> None:
        """Test case for update_tag

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Sonatype Lifecycle Public REST API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.196.0-01
    Contact: community@sonatype.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from sonatype_iq_api_client.models.api_dependency_tree_response_dto import ApiDependencyTreeResponseDTO

class TestApiDependencyTreeResponseDTO(unittest.TestCase):
    """ApiDependencyTreeResponseDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiDependencyTreeResponseDTO:
        """Test ApiDependencyTreeResponseDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiDependencyTreeResponseDTO`
        """
        model = ApiDependencyTreeResponseDTO()
        if include_optional:
            return ApiDependencyTreeResponseDTO(
                dependency_tree = sonatype_iq_api_client.models.api_dependency_tree_node_dto.ApiDependencyTreeNodeDTO(
                    children = [
                        sonatype_iq_api_client.models.api_dependency_tree_node_dto.ApiDependencyTreeNodeDTO(
                            component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                                coordinates = {
                                    'key' : ''
                                    }, 
                                format = '', ), 
                            direct = True, 
                            package_url = '', )
                        ], 
                    component_identifier = sonatype_iq_api_client.models.api_component_identifier_dtov2.ApiComponentIdentifierDTOV2(
                        format = '', ), 
                    direct = True, 
                    package_url = '', )
            )
        else:
            return ApiDependencyTreeResponseDTO(
        )
        """

    def testApiDependencyTreeResponseDTO(self):
        """Test ApiDependencyTreeResponseDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
